"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
exports.__esModule = true;
var React = require("react");
var Mark_1 = require("./Mark");
var utils_1 = require("./utils");
var Token = function (props) {
    var bold;
    if (props.wordsToBold && utils_1.makeBold(props.content, props.wordsToBold)) {
        bold = { fontWeight: 'bold' };
    }
    return React.createElement("span", { "data-i": props.i, style: bold },
        props.content,
        " ");
};
// TODO: When React 16.3 types are ready, remove casts.
var TokenAnnotator = /** @class */ (function (_super) {
    __extends(TokenAnnotator, _super);
    function TokenAnnotator(props) {
        var _this = _super.call(this, props) || this;
        _this.handleMouseUp = function () {
            var _a;
            var _b = _this.props, value = _b.value, waiting = _b.waiting;
            if (!_this.props.onChange)
                return;
            var response = {
                value: value,
                waiting: waiting
            };
            var selection = window.getSelection();
            if (utils_1.selectionIsEmpty(selection))
                return;
            if (!selection.anchorNode.parentElement.hasAttribute('data-i') ||
                !selection.focusNode.parentElement.hasAttribute('data-i')) {
                window.getSelection().empty();
                return false;
            }
            if (_this.props.waiting) {
                var wait = _this.props.waiting;
                response = _this.deleteWaiting({ start: wait.start, end: wait.end });
            }
            var start = parseInt(selection.anchorNode.parentElement.getAttribute('data-i'), 10);
            var end = parseInt(selection.focusNode.parentElement.getAttribute('data-i'), 10);
            if (utils_1.selectionIsBackwards(selection)) {
                ;
                _a = [end, start], start = _a[0], end = _a[1];
            }
            end += 1;
            if (_this.props.pre) {
                _this.props.onChange({
                    value: response.value.concat([
                        _this.getSpan({ start: start, end: end, tokens: _this.props.tokens.slice(start, end) }),
                    ])
                });
            }
            else {
                _this.props.onChange({
                    value: response.value.concat([
                        {
                            start: start,
                            end: end,
                            tokens: _this.props.tokens.slice(start, end),
                            tag: 'waiting...',
                            special_label: '',
                            color: '#84d2ff'
                        },
                    ]),
                    waiting: { start: start, end: end }
                });
            }
            window.getSelection().empty();
        };
        _this.handleSplitClick = function (_a) {
            var start = _a.start, end = _a.end;
            console.log('handleSplitClick');
            // Find and remove the matching split.
            var splitIndex = _this.props.value.findIndex(function (s) { return s.start === start && s.end === end; });
            if (splitIndex >= 0) {
                if (_this.props.pre) {
                    _this.props.onChange({ value: _this.props.value.slice(0, splitIndex).concat(_this.props.value.slice(splitIndex + 1)) });
                }
                else {
                    _this.props.onChange({ value: _this.props.value.slice(0, splitIndex).concat(_this.props.value.slice(splitIndex + 1)), waiting: null });
                }
            }
        };
        _this.deleteWaiting = function (_a) {
            var start = _a.start, end = _a.end;
            // Find and remove the matching split.
            var splitIndex = _this.props.value.findIndex(function (s) { return s.start === start && s.end === end; });
            if (splitIndex >= 0) {
                return { value: _this.props.value.slice(0, splitIndex).concat(_this.props.value.slice(splitIndex + 1)), waiting: null };
            }
        };
        _this.getSpan = function (span) {
            if (_this.props.getSpan)
                return _this.props.getSpan(span);
            return span;
        };
        _this.rootRef = React.createRef();
        return _this;
    }
    TokenAnnotator.prototype.componentDidMount = function () {
        this.rootRef.current.addEventListener('mouseup', this.handleMouseUp);
    };
    TokenAnnotator.prototype.componentWillUnmount = function () {
        this.rootRef.current.removeEventListener('mouseup', this.handleMouseUp);
    };
    TokenAnnotator.prototype.render = function () {
        var _this = this;
        var _a = this.props, tokens = _a.tokens, value = _a.value, style = _a.style, renderMark = _a.renderMark;
        var splits = utils_1.splitTokensWithOffsets(tokens, value);
        return (React.createElement("div", { style: style, ref: this.rootRef }, splits.map(function (split, i) {
            if (split.mark) {
                return (React.createElement(Mark_1["default"], __assign({}, split, { key: split.i, k: split.start + "-" + split.end, onClick: _this.handleSplitClick, onClickChange: _this.props.onClickChange, wordsToBold: _this.props.wordsToBold, showTags: _this.props.showTags })));
            }
            else {
                return React.createElement(React.Fragment, null,
                    React.createElement(Token, __assign({ key: split.i }, split, { wordsToBold: _this.props.wordsToBold, onClickChange: _this.props.onClickChange })));
            }
        })));
    };
    TokenAnnotator.defaultProps = {
        renderMark: function (props) { return React.createElement(Mark_1["default"], __assign({}, props)); },
        showTags: true,
        pre: true
    };
    return TokenAnnotator;
}(React.Component));
exports["default"] = TokenAnnotator;
//# sourceMappingURL=TokenAnnotator.js.map